@@ -1,7 +1,7 @@
 package Bb::Collaborate::Ultra::User;
 use warnings; use strict;
 use Mouse;
-extends 'Bb::Collaborate::Ultra';
+extends 'Bb::Collaborate::Ultra::DAO';
 
 =head1 NAME
 
@@ -11,6 +11,10 @@ Bb::Collaborate::Ultra::User - Launch Context User
 
 See also L<Bb::Collaborate::Ultra::LaunchContext>.
 
+=head2 METHODS
+
+See L<https://xx-csa.bbcollab.com/documentation#User>
+
 =cut
 
 has 'ltiLaunchDetails' => (isa => 'Any', is => 'rw');
